octo — Octo 0.2 documentation

### Navigation

- index
- modules |
- Octo 0.2 documentation »

# octo

- octo Package
  - `octo` Package
  - `exceptions` Module
  - `manager` Module
  - `plugin` Module

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- Octo 0.2 documentation »

© Copyright 2013, Nick Groenen. Created using Sphinx 1.2b1.